==> woomera-5.1.0.tar.gz: lib/src/core/simulated_headers.dart <==
part of core;

//================================================================
/// Headers in a simulated request or response

class SimulatedHttpHeaders extends HttpHeaders {
  final Map<String, List<String>> _data = <String, List<String>>{};

  //----------------------------------------------------------------

  @override
  void add(String name, Object value) {
    final lcName = name.toLowerCase();

    List<String> values;
    if (_data.containsKey(lcName)) {
      values = _data[lcName];
    } else {
      values = (_data[lcName] = <String>[]);
    }
    values.add(value.toString());
  }

  //----------------------------------------------------------------

  @override
  List<String> operator [](String name) => _data[name.toLowerCase()];

  //----------------------------------------------------------------

  @override
  String value(String name) {
    final lcName = name.toLowerCase();

    if (_data.containsKey(lcName)) {
      final values = _data[lcName];
      if (values.isEmpty) {
        return null;
      } else if (values.length == 1) {
        return values.first;
      } else {
        throw StateError('multiple values in header: $lcName');
      }
    } else {
      return null;
    }
  }

  //----------------------------------------------------------------

  @override
  void set(String name, Object value) {
    _data[name.toLowerCase()] = [value.toString()];
  }

  //----------------------------------------------------------------

  @override
  void remove(String name, Object value) {
    final lcName = name.toLowerCase();

    if (_data.containsKey(lcName)) {
      _data[lcName].remove(value);
    }
  }

  //----------------------------------------------------------------

  @override
  void removeAll(String name) {
    _data.remove(name.toLowerCase());
  }

  //----------------------------------------------------------------

  @override
  void forEach(void Function(String name, List<String> values) f) {
    for (var key in _data.keys) {
      f(key.toLowerCase(), _data[key]);
    }
  }

  //----------------------------------------------------------------

  @override
  void noFolding(String name) {}

  //----------------------------------------------------------------

  @override
  void clear() {
    _data.clear();
  }
}

==> woomera-6.0.0.tar.gz: lib/src/core/simulated_headers.dart <==
part of core;

//================================================================
/// Headers in a simulated request or response

class SimulatedHttpHeaders extends HttpHeaders {
  // Map from the lowercase value of the header name to the "current case" of
  // the header name. This is to support the `preserveHeaderCase` feature that
  // was introduced in Dart 2.8 for the [add] and [set] methods.

  final _originalHeaderNames = <String, String>{};

  // Map from the lowercase value of the header name to its values.

  final _data = <String, List<String>>{};

  //----------------------------------------------------------------

  @override
  void add(String name, Object value, {bool preserveHeaderCase = false}) {
    // Dart 2.8 adds the preserveHeaderCase option
    final lcName = name.toLowerCase();

    List<String> values;
    if (_data.containsKey(lcName)) {
      values = _data[lcName];
    } else {
      values = (_data[lcName] = <String>[]);
    }
    values.add(value.toString());

    _originalHeaderNames[lcName] = preserveHeaderCase ? name : lcName;
  }

  //----------------------------------------------------------------

  @override
  List<String> operator [](String name) => _data[name.toLowerCase()];

  //----------------------------------------------------------------

  @override
  String value(String name) {
    final lcName = name.toLowerCase();

    if (_data.containsKey(lcName)) {
      final values = _data[lcName];
      if (values.isEmpty) {
        return null;
      } else if (values.length == 1) {
        return values.first;
      } else {
        throw StateError('multiple values in header: $lcName');
      }
    } else {
      return null;
    }
  }

  //----------------------------------------------------------------

  @override
  void set(String name, Object value, {bool preserveHeaderCase = false}) {
    // Dart 2.8 adds the preserveHeaderCase option
    final lcName = name.toLowerCase();

    _data[lcName] = [value.toString()];

    _originalHeaderNames[lcName] = preserveHeaderCase ? name : lcName;
  }

  //----------------------------------------------------------------

  @override
  void remove(String name, Object value) {
    final lcName = name.toLowerCase();

    final values = _data[lcName];
    if (values != null) {
      values.remove(value);
      if (values.isEmpty) {
        _data.remove(lcName);
        _originalHeaderNames.remove(lcName);
      }
    }
  }

  //----------------------------------------------------------------

  @override
  void removeAll(String name) {
    final lcName = name.toLowerCase();

    _data.remove(lcName);
    _originalHeaderNames.remove(lcName);
  }

  //----------------------------------------------------------------

  @override
  void forEach(void Function(String name, List<String> values) f) {
    for (var key in _data.keys) {
      f(_originalHeaderNames[key], _data[key]);
    }
  }

  //----------------------------------------------------------------

  @override
  void noFolding(String name) {}

  //----------------------------------------------------------------

  @override
  void clear() {
    _data.clear();
    _originalHeaderNames.clear();
  }
}
